Middleware — Sneakpeek 0.2.2 documentation

# Middleware

Sneakpeek allows you to run arbitrary code before the request and after the response has been recieved. This can be helpful if you have some common logic you want to use in your scrapers.

There are some plugins that are already implemented:

- Rate limiter
- Robots.txt
- User Agent injector
- Proxy middleware
- Requests logging middleware
- Implementing your own middleware
  - Middleware implementation example